# API reference

## Non-windowed value holders

* `SIGN`
* `EMA`
* `HIGH`
* `LOW`
* `OPEN`
* `CLOSE`
* `SQRT`
* `DIFF`
* `RETURNSimple`
* `RETURNLog`
* `EXP`
* `LOG`
* `POW`
* `ABS`
* `ACOS`
* `ACOSH`
* `ASIN`
* `ASINH`
* `SHIFT`
* `IIF`
* `MAXIMUM`
* `MINIMUM`

## Windowed value holders

* `MACD`
* `RSI`
* `MA`
* `MIN`
* `QUANTILE`
* `ALLTRUE`
* `ANYTRUE`
* `SUM`
* `VAIRANCE`
* `STD`
* `NPOSITIVE`
* `MAPOSITIVE`
* `HIST`

## Cross-sectional value holders

* `CSRank`
* `CSMean`
* `CSMeanAdjusted`
* `CSQuantile`
* `CSZScore`
* `CSRes`
